@@ -107,6 +107,9 @@ void CDlgConfig::exec()
     checkAntiAliasing->setChecked(resources.m_useAntiAliasing);
     checkReducePoiIcons->setChecked(resources.m_reducePoiIcons);
 
+    spinZoomLevelThresholdPois->setValue(resources.m_zoomLevelThresholdPois);
+    spinZoomLevelThresholdPoiLabels->setValue(resources.m_zoomLevelThresholdPoiLabels);
+
     checkUseGeoDB->setChecked(resources.m_useGeoDB);
     groupSaveWks->setEnabled(resources.m_useGeoDB);
     checkGeoDBSaveOnExit->setChecked(resources.m_saveGeoDBOnExit);
@@ -121,6 +124,8 @@ void CDlgConfig::exec()
     comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
 
+	checkWatchDog->setChecked(resources.m_watchdogEnabled);
+
     comboDevBaudRate->addItem("4800");
     comboDevBaudRate->addItem("9600");
     comboDevBaudRate->addItem("19200");
@@ -230,6 +235,9 @@ void CDlgConfig::accept()
     resources.m_useAntiAliasing = checkAntiAliasing->isChecked();
     resources.m_reducePoiIcons  = checkReducePoiIcons->isChecked();
 
+    resources.m_zoomLevelThresholdPois      = spinZoomLevelThresholdPois->value();
+    resources.m_zoomLevelThresholdPoiLabels = spinZoomLevelThresholdPoiLabels->value();
+
     resources.m_useGeoDB        = checkUseGeoDB->isChecked();
     resources.m_saveGeoDBOnExit = checkGeoDBSaveOnExit->isChecked();
     resources.m_saveGeoDBMinutes = spinGeoDBMinutes->value();
@@ -240,6 +248,7 @@ void CDlgConfig::accept()
     resources.m_devIPPort       = lineDevIPPort->text().toUShort();
     resources.m_devSerialPort   = lineDevSerialPort->text();
     resources.m_devBaudRate     = comboDevBaudRate->currentText();
+	resources.m_watchdogEnabled = checkWatchDog->isChecked();
     resources.m_devType         = comboDevType->itemText(comboDevType->currentIndex());
     resources.m_devCharset      = comboDevCharset->itemText(comboDevCharset->currentIndex());
 
