@@ -34,6 +34,7 @@
 
 #include <QtGui>
 #include <QtNetwork>
+#include <tzdata.h>
 
 CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 : QDialog(parent)
@@ -140,7 +141,6 @@ int CDlgEditWpt::exec()
     oldLon = wpt.lon;
     oldLat = wpt.lat;
 
-    //TODO: that has to be metric/imperial
     if(wpt.ele != WPT_NOFLOAT)
     {
         IUnit::self().meter2elevation(wpt.ele, val, unit);
@@ -662,6 +662,7 @@ void CDlgEditWpt::triggerSpoilerDownload()
     pendingRequests.clear();
 
     QNetworkRequest request;
+    
     request.setUrl(wpt.link);
     networkAccessManager->get(request);
 }
@@ -709,10 +710,9 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
         return;
     }
 
-
     QRegExp re0(".*Object moved to <a href=\"(.*)\".*");
     QRegExp re1(".*CachePageImages.*");
-    QRegExp re2("(http://img.geocaching.com/cache/large/.*\\.jpg).*>(.*)</a>");
+    QRegExp re2("(http://.*\\.jpg).*>(.*)</a>");
 
     re2.setMinimal(true);
 
@@ -726,6 +726,7 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
             QString url  = re0.cap(1);
 
             QNetworkRequest request;
+            
             request.setUrl(url);
             networkAccessManager->get(request);
             return;
@@ -745,6 +746,7 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
                 QString text = re2.cap(2);
 
                 QNetworkRequest request;
+                
                 request.setUrl(url);
                 pendingRequests[networkAccessManager->get(request)] = text;
 
@@ -764,3 +766,5 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
     silentSpoilerQuery = false;
 
 }
+
+
