@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -302,10 +302,6 @@ void CMapGeoTiff::draw()
                         unsigned int offset;
 
                         for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++);
-                        /// @todo this has to be removed with GDAL 1.8.0
-#ifdef WIN32
-                        //offset = 3 - b;
-#endif   // WIN32
                         if(offset < sizeof(testPix))
                         {
                             quint8 * pTar   = img.bits() + offset;
