@@ -198,11 +198,19 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
         w->setTrackEditWidget(this);
     }
 
+    SETTINGS;
+    tabWidget->setCurrentIndex(cfg.value("TrackEditWidget/currentIndex",0).toUInt());
+    checkCenterMap->setChecked((cfg.value("TrackEditWidget/centerMap",true).toBool()));
+
 }
 
 
 CTrackEditWidget::~CTrackEditWidget()
 {
+    SETTINGS;
+    cfg.setValue("TrackEditWidget/currentIndex",tabWidget->currentIndex());
+    cfg.setValue("TrackEditWidget/centerMap",checkCenterMap->isChecked());
+
     if(!trackStatProfileDist.isNull())
     {
         delete trackStatProfileDist;
@@ -246,15 +254,42 @@ CTrackEditWidget::~CTrackEditWidget()
 
 void CTrackEditWidget::keyPressEvent(QKeyEvent * e)
 {
-    if(track.isNull()) return;
+    if(track.isNull()){e->ignore(); return;}
 
-    if(e->key() == Qt::Key_Delete)
+    switch (e->key())
     {
-        slotPurge();
-    }
-    else
-    {
-        QWidget::keyPressEvent(e);
+        case Qt::Key_Delete:
+        {
+            slotPurge();
+            break;
+        }
+
+        case Qt::Key_Left:
+        {
+            QList<QTreeWidgetItem*> items = treePoints->selectedItems();
+            if (items.begin() != items.end())
+            {
+                originator = true;
+                track->setPointOfFocus((*items.begin())->data(0,Qt::UserRole).toInt(), CTrack::eNoErase, true);
+                originator = false;
+            }
+            break;
+        }
+
+        case Qt::Key_Right:
+        {
+            QList<QTreeWidgetItem*> items = treePoints->selectedItems();
+            if (items.begin() != items.end())
+            {
+                originator = true;
+                track->setPointOfFocus((*(--items.end()))->data(0,Qt::UserRole).toInt(), CTrack::eNoErase, true);
+                originator = false;
+            }
+            break;
+        }
+
+        default:
+            e->ignore();
     }
 }
 
@@ -503,7 +538,6 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 
     slotUpdate();
 
-    //TODO: resize of the TrackEditWidget
     SETTINGS;
     // restore last session position and size of TrackEditWidget
     if ( cfg.contains("TrackEditWidget/geometry"))
@@ -556,8 +590,6 @@ void CTrackEditWidget::slotUpdate()
     }
 
 #ifdef GPX_EXTENSIONS
-    //TODO: endable ext. sym. only when there are exts
-
     //get names and number of extensions
                                  //Anzahl der Extensions
     QList<QString> names_of_ext = track->tr_ext.set.toList();
@@ -737,7 +769,7 @@ void CTrackEditWidget::slotUpdate()
         item->setText(eDescend, tr("%1 %2").arg(val).arg(unit));
 
         // speed
-        if(trkpt->speed > 0)
+        if(trkpt->speed != WPT_NOFLOAT)
         {
             IUnit::self().meter2speed(trkpt->speed, val, unit);
             str = tr("%1 %2").arg(val).arg(unit);
@@ -809,11 +841,26 @@ void CTrackEditWidget::slotPointSelectionChanged()
 
     //    qDebug() << Q_FUNC_INFO;
 
+    qint32 old_b = -1;
+    qint32 old_e = -1;
+    qint32 new_b = -1;
+    qint32 new_e = -1;
+    qint32 i = -1;
+
     // reset previous selections
     QList<CTrack::pt_t>& trkpts           = track->getTrackPoints();
     QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
     while(trkpt != trkpts.end())
     {
+        i++;
+        if ((trkpt->flags & CTrack::pt_t::eSelected) != 0)
+        {
+            if (old_b < 0)
+            {
+                old_b = i;
+            }
+            old_e = i;
+        }
         trkpt->flags &= ~CTrack::pt_t::eFocus;
         trkpt->flags &= ~CTrack::pt_t::eSelected;
         ++trkpt;
@@ -827,6 +874,11 @@ void CTrackEditWidget::slotPointSelectionChanged()
         quint32 idxTrkPt = (*item)->data(0,Qt::UserRole).toUInt();
         //trkpts[idxTrkPt].flags |= CTrack::pt_t::eFocus;
         trkpts[idxTrkPt].flags |= CTrack::pt_t::eSelected;
+        if (new_b < 0)
+        {
+            new_b = idxTrkPt;
+        }
+        new_e = idxTrkPt;
         ++item;
     }
     if(!items.isEmpty())
@@ -836,6 +888,20 @@ void CTrackEditWidget::slotPointSelectionChanged()
     }
 
     originator = true;
+    if (checkCenterMap->isChecked())
+    {
+        if (items.begin() != items.end())
+        {
+            if (old_e != new_e)
+            {
+                track->setPointOfFocus(new_e, CTrack::eNoErase, true);
+            }
+            else
+            {
+                track->setPointOfFocus(new_b, CTrack::eNoErase, true);
+            }
+        }
+    }
     //track->rebuild(false);
     track->emitSigNeedUpdate();
     originator = false;
@@ -1030,13 +1096,11 @@ void CTrackEditWidget::slotToggleExtensionsGraph()
     theMainWindow->getCanvasTab()->setTabPosition(QTabWidget::South);
     theMainWindow->getCanvasTab()->setMovable(true);
 
-    //TODO: make tabs closeable
     theMainWindow->getCanvasTab()->setTabsClosable(true);
 }
 #endif
 
 #ifdef GPX_EXTENSIONS
-//TODO: method to switch on/off standard columns in track view
 void CTrackEditWidget::slotSetColumns(bool checked)
 {
     //who made the signal
@@ -1110,7 +1174,6 @@ void CTrackEditWidget::slotSetColumns(bool checked)
 #endif
 
 #ifdef GPX_EXTENSIONS
-//TODO: switch extension columns on/off
 void CTrackEditWidget::slotSetColumnsExt(bool checked)
 {
     //who's sender of checkbox signal
@@ -1124,7 +1187,6 @@ void CTrackEditWidget::slotSetColumnsExt(bool checked)
 }
 #endif
 
-//TODO: Show Track in Google Maps
 void CTrackEditWidget::slotGoogleMaps()
 {
     QString str, outp;
@@ -1193,7 +1255,6 @@ void CTrackEditWidget::slotGoogleMaps()
 }
 
 
-//TODO: Close Tab
 void CTrackEditWidget::slotKillTab(int index)
 {
     if (index != 0)
@@ -1433,7 +1494,7 @@ void CTrackEditWidget::slotMultiColorConfig()
 
     CTrack::multi_color_setup_t& setup = track->getMultiColorSetup(comboMultiColor->currentIndex());
     CDlgMultiColorConfig dlg(setup);
-    if(dlg.exec() == QDialog::QDialog::Rejected)
+    if(dlg.exec() == QDialog::Rejected)
     {
         return;
     }
