@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -488,11 +488,11 @@ bool CWpt::hasHiddenInformation()
 
 QString CWpt::getInfo()
 {
-    QString str = getName();
+    QString str /*= getName()*/;
 
     if(geocache.hasData)
     {
-        str += QString(" (%1, D %2, T %3)").arg(geocache.container).arg(geocache.difficulty, 0,'f',1).arg(geocache.terrain, 0,'f',1);
+        str += QString("%4 (%1, D %2, T %3)").arg(geocache.container).arg(geocache.difficulty, 0,'f',1).arg(geocache.terrain, 0,'f',1).arg(geocache.name);
     }
 
     if(timestamp != 0x00000000 && timestamp != 0xFFFFFFFF)
@@ -981,8 +981,8 @@ void CWpt::saveGcExt(QDomElement& gpxCache, bool isExport)
             gpxLogs.appendChild(gpxLog);
 
             gpxLog.setAttribute("id", log.id);
-            setEntry("date", log.date, gpx, gpxLog);
-            setEntry("type", log.type, gpx, gpxLog);
+            setEntry("groundspeak:date", log.date, gpx, gpxLog);
+            setEntry("groundspeak:type", log.type, gpx, gpxLog);
 
             QDomElement finder = gpx.createElement("groundspeak:finder");
             gpxLog.appendChild(finder);
@@ -991,7 +991,7 @@ void CWpt::saveGcExt(QDomElement& gpxCache, bool isExport)
             finder.appendChild(_finder_);
             finder.setAttribute("id", log.finderId);
 
-            setEntryHtml("text", log.text, gpx, gpxLog);
+            setEntryHtml("groundspeak:text", log.text, gpx, gpxLog);
         }
     }
 }
