@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -33,7 +33,7 @@
 
 #include "CApplication.h"
 #include "CMainWindow.h"
-#include "CGarminTyp.h"          //TODO: this shall not be commented out when building a debug version with Visual Studio 2005
+#include "CGarminTyp.h"
 
 #include "config.h"
 #include "version.h"
